@@ -1,5 +1,5 @@
 /* The Ace of Penguins - test6.c
-   Copyright (C) 1998 DJ Delorie
+   Copyright (C) 1998, 2001 DJ Delorie
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,15 +26,16 @@ Picture *card, *test6;
 int
 main(int argc, char **argv)
 {
-  init_table(argc, argv, 3*M+2*W, 2*M+H);
+  init_ace(argc, argv);
+  init_table(3*M+2*W, 2*M+H);
   table_loop();
 }
 
 void
 init()
 {
-  card = get_picture("card/as.gif");
-  test6 = get_picture("test6.gif");
+  card = get_picture("as");
+  test6 = get_picture("test6");
 }
 
 void
